==> blog-1.2-src.tar.gz: blog-1.2/src/java/jp/sf/pal/blog/BlogConstants.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.blog;

public class BlogConstants
{
    public static final String UTF_8 = "UTF-8";

    public static final String HTML_FORMAT_TYPE = "HTML";

    public static final String TEXT_FORMAT_TYPE = "TEXT";

    public static final String HATENA_FORMAT_TYPE = "HATENA";

    public static final int DEFAULT_PAGE_SIZE = 10;

    public static final int DEFAULT_TITLE_MAX_LENGTH = 20;

    public static final String TRUE = Boolean.TRUE.toString();

    public static final String FALSE = Boolean.FALSE.toString();

    public static final String TITLE_VIEW_OWNER = "TITLE_VIEW_OWNER";

    public static final String TITLE_VIEW_SORT_COLUMN = "TITLE_VIEW_SORT_COLUMN";

    public static final String TITLE_VIEW_PAGE_SIZE = "TITLE_VIEW_PAGE_SIZE";

    public static final String TITLE_VIEW_DISPLAY_CREATEDTIME = "TITLE_VIEW_DISPLAY_CREATEDTIME";

    public static final String TITLE_VIEW_DISPLAY_UPDATEDTIME = "TITLE_VIEW_DISPLAY_UPDATEDTIME";

    public static final String VIEW_OWNER = "VIEW_OWNER";

    public static final String VIEW_PAGE_SIZE = "VIEW_PAGE_SIZE";

    public static final String NONEXISTENT_VALUE = "-";

    public static final String BLOG_URL = "BLOG_URL";

    public static final String BLOG_REDIRECT_ID = "redirectForm:blogid";

    // for Portlet Messaging

    public static final String BLOG_ALL_TOPIC = "BLOG_ALL_TOPIC";

    public static final String BLOG_EDIT_TOPIC = "BLOG_EDIT_TOPIC";

    public static final String BLOG_VIEW_TOPIC = "BLOG_VIEW_TOPIC";

    public static final String BLOG_MESSAGE_ID = "BLOG_MESSAGE_ID";

    // View Mode

    public static final String BLOG_LIST_VIEW = "ListView";

    public static final String BLOG_CONTENT_VIEW = "ContentView";

    public static final String COMMENT_ENABLED = "comment-enabled";

    public static final String TRACKBACK_ENABLED = "trackback-enabled";

}

==> blog-1.3-src.tar.gz: blog-1.3/src/java/jp/sf/pal/blog/BlogConstants.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.blog;

public class BlogConstants
{
    public static final String UTF_8 = "UTF-8";

    public static final String CONVERTER_LIST = "Converters";

    public static final String IMPORTER_LIST = "Importers";

    public static final int DEFAULT_PAGE_SIZE = 10;

    public static final int DEFAULT_TITLE_MAX_LENGTH = 20;

    public static final String TRUE = Boolean.TRUE.toString();

    public static final String FALSE = Boolean.FALSE.toString();

    public static final String TITLE_VIEW_OWNER = "TITLE_VIEW_OWNER";

    public static final String TITLE_VIEW_SORT_COLUMN = "TITLE_VIEW_SORT_COLUMN";

    public static final String TITLE_VIEW_PAGE_SIZE = "TITLE_VIEW_PAGE_SIZE";

    public static final String TITLE_VIEW_DISPLAY_CREATEDTIME = "TITLE_VIEW_DISPLAY_CREATEDTIME";

    public static final String TITLE_VIEW_DISPLAY_UPDATEDTIME = "TITLE_VIEW_DISPLAY_UPDATEDTIME";

    public static final String VIEW_OWNER = "VIEW_OWNER";

    public static final String VIEW_PAGE_SIZE = "VIEW_PAGE_SIZE";

    public static final String NONEXISTENT_VALUE = "-";

    public static final String BLOG_URL = "BLOG_URL";

    public static final String BLOG_REDIRECT_ID = "blogid";

    // for Portlet Messaging

    public static final String BLOG_ALL_TOPIC = "BLOG_ALL_TOPIC";

    public static final String BLOG_EDIT_TOPIC = "BLOG_EDIT_TOPIC";

    public static final String BLOG_VIEW_TOPIC = "BLOG_VIEW_TOPIC";

    public static final String BLOG_MESSAGE_ID = "BLOG_MESSAGE_ID";

    // View Mode

    public static final String BLOG_LIST_VIEW = "ListView";

    public static final String BLOG_CONTENT_VIEW = "ContentView";

    public static final String COMMENT_ENABLED = "comment-enabled";

    public static final String TRACKBACK_ENABLED = "trackback-enabled";

}
